import glob from "fast-glob";
import { writeJSON } from "fs-extra";
import { trimSuffix } from "@kubernetes-models/string-util";
import { extname } from "path";
const CJS_EXT = ".js";
const ESM_EXT = ".mjs";
export async function generate(args) {
    const paths = await glob(["**/*.ts", "!**/*.d.ts"], {
        cwd: args.path
    });
    const exportMap = {};
    for (const path of paths) {
        if (path.startsWith("_"))
            continue;
        const base = trimSuffix(path, extname(path));
        const exportPath = base === "index" ? "." : `./${trimSuffix(base, "/index")}`;
        const requirePath = `./${base}${CJS_EXT}`;
        const importPath = `./${base}${ESM_EXT}`;
        exportMap[exportPath] = {
            require: requirePath,
            import: importPath
        };
    }
    await writeJSON(args.export, exportMap, {
        spaces: 2
    });
    console.log("Generated export map in %s", args.export);
}
//# sourceMappingURL=generate.mjs.map